@@ -1,5 +1,6 @@
 import requests
 import lxml.etree as et
+from null_parser import Null_Parser
 
 class NSLDS():
 
@@ -21,6 +22,11 @@ class NSLDS():
         self.pin = kwargs.get('pin')
         self.session_id = None
 
+    def parse_loan_data(self, loan_data, parser=Null_Parser()):
+        parsed_data = parser.parse_textfile(loan_data)
+        return parsed_data
+
+
     def get_loan_data(self):
         #Create Session
         s = requests.Session()
